@@ -276,11 +276,16 @@ class RequestInitMiddleware:
     
     # see if a function is specified with the page (the . separates a function name)
     du_pos = request.dmp_router_page.find('.')
-    if du_pos < 0:
-      request.dmp_router_function = 'process_request'
-    else:
+    if du_pos >= 0:
       request.dmp_router_function = request.dmp_router_page[du_pos+1:]
       request.dmp_router_page = request.dmp_router_page[:du_pos]
+    else:
+      du_pos = request.dmp_router_page.find('__')  # __ can also separate the function name, this is a deprecated way to do it - we'll support it for the near future
+      if du_pos >= 0:
+        request.dmp_router_function = request.dmp_router_page[du_pos+2:]
+        request.dmp_router_page = request.dmp_router_page[:du_pos]
+      else:  # the . not found, and the __ not found, so go to default function name
+        request.dmp_router_function = 'process_request'
       
     # set up the urlparams with the reamining path parts
     request.urlparams = URLParamList([ urllib.parse.unquote_plus(s) for s in path_parts[2:] ])
